<template>
    <div element-loading-text="数据加载中..." element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)" v-loading.fullscreen.lock="markLoading">
        <el-dialog title="编辑" :visible="formVisible" :before-close="handleClose" :close-on-click-modal="false"
            :destroy-on-close="true" width="50%" top="6vh" :class="[reqLoading ? 'dialog-box' : '']">
            <div v-loading="reqLoading" element-loading-text="加载中..." element-loading-spinner="el-icon-loading"
                element-loading-background="rgba(255, 255, 255, 1)">
                <div style="text-align: center;margin-bottom: 10px;font-size: 14px;">{{ parameter.projectName }}</div>
                <el-form ref="form" label-position="top" :rules="rules" :model="parameter" label-width="150px">
                    <div class="table-div">
                        <el-row :gutter="24" justify="start" type="flex" class="flex-wrap">
                            <el-col :span="8">
                                <el-form-item label="推广方式" :rules="rules.promotionType">
                                    <dict-select dictCode="tgxs" :hasDefaultOption="true" clearable
                                        v-model="parameter.promotionType" style="width: 100%" placeholder="请选择推广方式" />
                                </el-form-item>
                            </el-col>
                            <el-col :span="8">
                                <el-form-item label="推广日期" :rules="rules.promotionDate">
                                    <el-date-picker value-format="yyyy-MM-dd" style="width:100%" format="yyyy/MM/dd"
                                        v-model="parameter.promotionDate" placeholder="请选择推广日期"
                                        type="date"></el-date-picker>
                                </el-form-item>
                            </el-col>
                            <el-col :span="24">
                                <el-form-item label="具体情况简介" :rules="rules.promotionContent">
                                    <el-input type="textarea" rows="10" maxlength="300" show-word-limit
                                        v-model="parameter.promotionContent" placeholder="请输入具体情况简介"></el-input>
                                </el-form-item>
                            </el-col>
                            <el-col :span="24">
                                附件
                                <el-col :span="12">
                                    <FileList :fileList="parameter.defaultFileList"></FileList>
                                </el-col>
                            </el-col>
                        </el-row>
                    </div>
                </el-form>
            </div>
            <div slot="footer" class="dialog-footer" :style="reqLoading ? 'position: relative;z-index: -1;' : ''">
                <el-button type="primary" @click="updateSave">保存</el-button>
                <el-button @click="handleClose">取消</el-button>
            </div>
        </el-dialog>
    </div>
</template>
  
<script>
import FileList from '@/components/uploadFile/FileList.vue'
import req from '@/request.js'
import { TableMixin } from '@/mixins/tableMixin'
const portal = window.context.portal
export default {
    name: 'ExperHisUpDate',
    components: {
        FileList
    },
    mixins: [TableMixin],
    data() {
        return {
            formVisible: false,
            reqLoading: false,
            markLoading: false,
            dialogVisible: false,
            rules: {
                promotionContent: [
                    { required: true, message: '请输入具体情况简介', trigger: 'change' }
                ],
                promotionType: [
                    { required: true, message: '请选择推广方式', trigger: 'change' }
                ],
                promotionDate: [
                    { required: true, message: '请选择推广日期', trigger: 'change' }
                ]
            },
            parameter: {}
        }
    },

    created() { },
    methods: {
        //
        openForm(item) {
            this.parameter = item
            this.getFiles(item.id)
            this.formVisible = true
        },
        updateSave() {
            this.$confirm('确认保存修改？', '更新提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'success'
            }).then(() => {
                this.markLoading = true
                req.put(portal + `/majorProjects/bizPilotExperiencePush/v1/`, this.parameter).then(res => {
                    console.log(res);
                    if (res.data.state) {
                        console.log(res);
                        this.$message.success('修改保存成功')
                        this.handleClose()
                        this.$emit('flushed')
                    }
                    this.markLoading = false
                })
            })
        },
        // 附件查询
        getFiles(id) {
            this.reqLoading = true
            let data = {
                pageBean: {
                    page: 1,
                    pageSize: -1
                },
                querys: [{
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'biz_id_',
                    relation: 'AND',
                    value: id
                }]
            }
            req.post(portal + `/file/v1/query`, data).then(res => {
                this.$set(this.parameter, 'files', res.data.rows)
                this.reqLoading = false
            })
        },
        // ------------
        handleClose() {
            this.parameter = {}
            this.formVisible = false
        }
    }
}
</script>
  
<style lang="scss" scoped>
@import '~@/assets/css/element-variables.scss';

.add-btn {
    font-weight: bold;
    cursor: pointer;
    color: $--color-primary;
}

.del-btn {
    font-weight: bold;
    color: $--color-danger;
    cursor: pointer;
}

.btn_icon {
    font-size: 20px;
    font-weight: 600;
    margin: 0 5px;
    padding: 5px 5px;
}

.btn_icon:hover {
    cursor: pointer;
}

.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;

    &:nth-child(1) {
        margin-right: 5px;
    }

    &:nth-child(1):hover {
        background-color: #2761ff;
        color: #fff;
    }

    &:nth-child(2):hover {
        background-color: #2761ff;
        color: #fff;
        border-color: #2761ff;
    }

    /deep/ i,
    span {
        font-size: 14px;
    }
}

/deep/.el-descriptions__header {
    margin: 15px 0 0 0;

    .el-descriptions__title {
        font-weight: normal;
    }
}

.file-item {
    display: flex;
    justify-content: space-between;
    width: 100%;
    padding: 5px 5px 5px 0;

    a {
        margin: 0 10px;
        user-select: none;
    }

    .file-name {
        max-width: 220px;
        height: 22px;
        overflow: hidden;
        white-space: nowrap;
        text-overflow: ellipsis;
    }
}

.file-item:hover {
    background-color: #f5f5f5;
    border-radius: 2px;
}

.ggbb_wjyj {
    display: flex;
    align-items: flex-end;
    margin-bottom: 1.14583vw;
    box-sizing: border-box;

    .symbol-num {
        text-align: center;

        &:first-child {
            max-width: 220px;
        }

        &:nth-child(3) {
            max-width: 100px;
            text-align: center;
        }

        &:last-child {
            max-width: 100px;
            text-align: center;
        }

        span {
            display: block;
        }
    }
}

.margin-bottom {
    margin-bottom: 15px;
}

/deep/.el-input__inner::-webkit-outer-spin-button,
/deep/.el-input__inner::-webkit-inner-spin-button {
    -webkit-appearance: none;
}

.form-mark {
    /deep/.el-input__inner {
        border-color: #f56c6c !important;
    }

    .error-info {
        color: #f56c6c;
        font-size: 0.625vw;
        line-height: 1;
        padding-top: 0.20833vw;
        position: absolute;
        top: 100%;
        left: 0;
    }
}

.mark {
    /deep/.el-form-item__label::before {
        content: '*';
        color: #f56c6c;
        margin-right: 0.20833vw;
    }
}

.dialog-footer {
    display: flex;
    justify-content: flex-end;
}

.input_placeholder {
    /deep/input::-webkit-input-placeholder {
        color: #606266;
        font-size: 12px;
    }
}

//加载遮罩
/deep/.el-dialog__body {
    box-sizing: border-box;

    .el-loading-parent--relative {
        max-height: inherit;
    }
}

.dialog-box {
    /deep/.el-dialog__body {
        overflow: hidden;
    }
}

.table-div {
    position: relative;
    border: 1px dashed #999;
    padding: 15px;
    border-radius: 5px;
    margin-bottom: 10px;

    &:hover {
        border: 1px dashed #2761ff;
        transition: all 0.3s;

        >.add-btn {
            opacity: 1;
            z-index: inherit;
            transition: all 0.3s;
        }
    }

    .add-btn {
        position: absolute;
        right: 15px;
        opacity: 0;
        z-index: -1;
        transition: all 0.3s;

        a {
            font-size: 20px;
            font-weight: 600;
            z-index: 2;
        }

        :last-child {
            margin-left: 10px;
        }
    }
}
</style>
  